@@ -15,11 +15,13 @@ from django.db.models.fields.files import FieldFile
 from django.forms import model_to_dict
 from django.utils import timezone
 
-from python_utils.imports import import_optional_dependency
 from python_utils.db import fetch_all
+from python_utils.imports import import_optional_dependency
 
 Model_T = TypeVar('Model_T', bound=Model)
 
+logger = logging.getLogger(__name__)
+
 
 class ExtendedEncoder(DjangoJSONEncoder):  # pragma no cover
     """Custom JSON Encoder that processes fields like date etc."""
@@ -32,15 +34,15 @@ class ExtendedEncoder(DjangoJSONEncoder):  # pragma no cover
         return super().default(o)
 
 
-def record_to_dict(record: Model, exclude: List = None) -> Dict:
+def record_to_dict(record: Model_T, exclude: List = None) -> Dict:
     """
     Transform a django record to a dict.
 
     Args:
-        record: to be transformed to dict
+        record: django object to be transformed to dict
         exclude: list of keys/fields to exclude in the final dict
     Returns:
-        dict with model filed:value pair
+        dict with model's field:value pairs
     """
 
     if exclude is None:
@@ -216,7 +218,7 @@ def compute_grouped_weighted_average_subquery(
 
 def update_record(record: Model_T, save=True, **data) -> Model_T:
     """
-    Update a record (as lazy model) and return it.
+    Update a record with given attributes and return it.
     If save=True also commit to the database the record with the changes
 
     Args:
@@ -255,7 +257,7 @@ def get_choice_value(choices, human_string: str) -> Optional[Union[int, str]]:
 
 def get_or_none(records: models.QuerySet, *args, **kwargs) -> Optional[Model_T]:
     """
-    Return object or None if not found.
+    Wrapper around queryset.get to return None if no record is found
 
     Args:
         records: queryset of objects to get() from
@@ -272,7 +274,7 @@ def get_or_none(records: models.QuerySet, *args, **kwargs) -> Optional[Model_T]:
 
 def ids(queryset: models.QuerySet, attr='id') -> List[Any]:
     """
-    Given a queryset and an attr we get all distinct values as a list
+    Given a queryset and an attr, get all distinct values of the attr as a list
 
     Args:
         queryset: queryset with the objects we want to get the data from
@@ -425,8 +427,8 @@ def safe_bulk_create(
     refresh fields (foreign keys) if any.
 
     Args:
-        model: Model.__class__ obj
-        records: list of records to be created
+        model: The Model to which the records belong
+        records: list of objects to be commited to the database
         refresh_fields: list with foreign keys to be updated
         batch_size: how many records we want to insert with a single query
     """
@@ -441,7 +443,7 @@ def safe_bulk_create(
                 except AttributeError:
                     continue
 
-    model.objects.bulk_create(records, batch_size=batch_size)
+    return model.objects.bulk_create(records, batch_size=batch_size)
 
 
 def safe_bulk_update(
@@ -482,18 +484,17 @@ def safe_bulk_update(
         timestamp = timezone.now()
         for record in records:
             setattr(record, updated_at_field, timestamp)
-    model.objects.bulk_update(records, fields, batch_size=batch_size)
 
-
-logger = logging.getLogger(__name__)
+    return model.objects.bulk_update(records, fields, batch_size=batch_size)
 
 
 def call_procedure(procedure_name: str, params: List[Any] = None):
     """
-    Executes a procedure in the db
+    Execute an SQL procedure in the db.
+
     Args:
         procedure_name: the name of the procedure to be executed
-        params: list of the parameters (maybe needs to be deleted)
+        params: list of the parameters to pass to the procedure
     """
     temp_time = time.time()
     logger.info(f"Started Procedure {procedure_name}")
